@@ -4,7 +4,7 @@ use warnings;
 
 package App::MP4Meta::MusicVideo;
 {
-  $App::MP4Meta::MusicVideo::VERSION = '1.130100';
+  $App::MP4Meta::MusicVideo::VERSION = '1.130160';
 }
 
 # ABSTRACT: Add metadata to a music video
@@ -57,7 +57,7 @@ sub _parse_filename {
     my ( $self, $file ) = @_;
 
     # strip suffix
-    $file =~ s/\.m4v$//;
+    $file = $self->_strip_suffix($file);
 
     if ( $file =~ /^(.*) - (.*)$/ ) {
         return ( $self->_clean_title($1), $self->_clean_title($2) );
@@ -78,7 +78,7 @@ App::MP4Meta::MusicVideo - Add metadata to a music video
 
 =head1 VERSION
 
-version 1.130100
+version 1.130160
 
 =head1 SYNOPSIS
 
