@@ -4,7 +4,7 @@ use warnings;
 
 package App::MP4Meta::TV;
 {
-  $App::MP4Meta::TV::VERSION = '1.130100';
+  $App::MP4Meta::TV::VERSION = '1.130160';
 }
 
 # ABSTRACT: Add metadata to a TV Series
@@ -139,7 +139,7 @@ sub _parse_filename {
     my ( $self, $file ) = @_;
 
     # strip suffix
-    $file =~ s/\.m4v$//;
+    $file = $self->_strip_suffix($file);
 
     # see if we have a regex that matches
     for my $r (@file_regexes) {
@@ -180,7 +180,7 @@ App::MP4Meta::TV - Add metadata to a TV Series
 
 =head1 VERSION
 
-version 1.130100
+version 1.130160
 
 =head1 SYNOPSIS
 
